---
title: <span class="badge builder"></span> FrameGeometrySource
---
# <span class="badge builder"></span> FrameGeometrySource

## Constructor

```python
FrameGeometrySource()
```
## Methods

### <span class="badge object-method"></span> build

Builds the object.

```python
def build() -> common.FrameGeometrySource
```

### <span class="badge object-method"></span> gazetteer

Path to Gazetteer

```python
def gazetteer(gazetteer: str) -> typing.Self
```

### <span class="badge object-method"></span> geohash

Field mappings

```python
def geohash(geohash: str) -> typing.Self
```

### <span class="badge object-method"></span> latitude

```python
def latitude(latitude: str) -> typing.Self
```

### <span class="badge object-method"></span> longitude

```python
def longitude(longitude: str) -> typing.Self
```

### <span class="badge object-method"></span> lookup

```python
def lookup(lookup: str) -> typing.Self
```

### <span class="badge object-method"></span> mode

```python
def mode(mode: common.FrameGeometrySourceMode) -> typing.Self
```

### <span class="badge object-method"></span> wkt

```python
def wkt(wkt: str) -> typing.Self
```

## See also

 * <span class="badge object-type-class"></span> [FrameGeometrySource](./object-FrameGeometrySource.md)
